@@ -206,12 +206,6 @@ class Setting:
         Default is 0. Automatically set to 1 on CI environments for robust testing.
         """
 
-        self.PIPENV_MAX_ROUNDS = int(os.environ.get("PIPENV_MAX_ROUNDS", "16"))
-        """Tells Pipenv how many rounds of resolving to do for Pip-Tools.
-
-        Default is 16, an arbitrary number that works most of the time.
-        """
-
         self.PIPENV_MAX_SUBPROCESS = int(os.environ.get("PIPENV_MAX_SUBPROCESS", "8"))
         """How many subprocesses should Pipenv use when installing.
 
@@ -403,8 +397,7 @@ class Setting:
         return self.PIPENV_VERBOSITY <= threshold
 
 
-def is_using_venv():
-    # type: () -> bool
+def is_using_venv() -> bool:
     """Check for venv-based virtual environment which sets sys.base_prefix"""
     if getattr(sys, "real_prefix", None) is not None:
         # virtualenv venvs
