@@ -20,7 +20,7 @@ from itertools import chain
 from typing import DefaultDict, Iterable, List, Optional, Set, Tuple
 
 from pipenv.patched.notpip._vendor.packaging import specifiers
-from pipenv.patched.notpip._vendor.pkg_resources import Distribution
+from pipenv.patched.notpip._vendor.packaging.requirements import Requirement
 
 from pipenv.patched.notpip._internal.cache import WheelCache
 from pipenv.patched.notpip._internal.exceptions import (
@@ -28,9 +28,11 @@ from pipenv.patched.notpip._internal.exceptions import (
     DistributionNotFound,
     HashError,
     HashErrors,
+    NoneMetadataError,
     UnsupportedPythonVersion,
 )
 from pipenv.patched.notpip._internal.index.package_finder import PackageFinder
+from pipenv.patched.notpip._internal.metadata import BaseDistribution
 from pipenv.patched.notpip._internal.models.link import Link
 from pipenv.patched.notpip._internal.operations.prepare import RequirementPreparer
 from pipenv.patched.notpip._internal.req.req_install import (
@@ -41,8 +43,8 @@ from pipenv.patched.notpip._internal.req.req_set import RequirementSet
 from pipenv.patched.notpip._internal.resolution.base import BaseResolver, InstallRequirementProvider
 from pipenv.patched.notpip._internal.utils.compatibility_tags import get_supported
 from pipenv.patched.notpip._internal.utils.logging import indent_log
-from pipenv.patched.notpip._internal.utils.misc import dist_in_usersite, normalize_version_info
-from pipenv.patched.notpip._internal.utils.packaging import check_requires_python, get_requires_python
+from pipenv.patched.notpip._internal.utils.misc import normalize_version_info
+from pipenv.patched.notpip._internal.utils.packaging import check_requires_python
 
 logger = logging.getLogger(__name__)
 
@@ -50,7 +52,7 @@ DiscoveredDependencies = DefaultDict[str, List[InstallRequirement]]
 
 
 def _check_dist_requires_python(
-    dist: Distribution,
+    dist: BaseDistribution,
     version_info: Tuple[int, int, int],
     ignore_requires_python: bool = False,
 ) -> None:
@@ -66,14 +68,21 @@ def _check_dist_requires_python(
     :raises UnsupportedPythonVersion: When the given Python version isn't
         compatible.
     """
-    requires_python = get_requires_python(dist)
+    # This idiosyncratically converts the SpecifierSet to str and let
+    # check_requires_python then parse it again into SpecifierSet. But this
+    # is the legacy resolver so I'm just not going to bother refactoring.
+    try:
+        requires_python = str(dist.requires_python)
+    except FileNotFoundError as e:
+        raise NoneMetadataError(dist, str(e))
     try:
         is_compatible = check_requires_python(
-            requires_python, version_info=version_info
+            requires_python,
+            version_info=version_info,
         )
     except specifiers.InvalidSpecifier as exc:
         logger.warning(
-            "Package %r has an invalid Requires-Python: %s", dist.project_name, exc
+            "Package %r has an invalid Requires-Python: %s", dist.raw_name, exc
         )
         return
 
@@ -84,7 +93,7 @@ def _check_dist_requires_python(
     if ignore_requires_python:
         logger.debug(
             "Ignoring failed Requires-Python check for package %r: %s not in %r",
-            dist.project_name,
+            dist.raw_name,
             version,
             requires_python,
         )
@@ -92,7 +101,7 @@ def _check_dist_requires_python(
 
     raise UnsupportedPythonVersion(
         "Package {!r} requires a different Python: {} not in {!r}".format(
-            dist.project_name, version, requires_python
+            dist.raw_name, version, requires_python
         )
     )
 
@@ -194,7 +203,7 @@ class Resolver(BaseResolver):
         """
         # Don't uninstall the conflict if doing a user install and the
         # conflict is not a user install.
-        if not self.use_user_site or dist_in_usersite(req.satisfied_by):
+        if not self.use_user_site or req.satisfied_by.in_usersite:
             req.should_reinstall = True
         req.satisfied_by = None
 
@@ -303,7 +312,7 @@ class Resolver(BaseResolver):
                 req.original_link_is_in_wheel_cache = True
             req.link = cache_entry.link
 
-    def _get_dist_for(self, req: InstallRequirement) -> Distribution:
+    def _get_dist_for(self, req: InstallRequirement) -> BaseDistribution:
         """Takes a InstallRequirement and returns a single AbstractDist \
         representing a prepared variant of the same.
         """
@@ -378,11 +387,11 @@ class Resolver(BaseResolver):
 
         more_reqs: List[InstallRequirement] = []
 
-        def add_req(subreq: Distribution, extras_requested: Iterable[str]) -> None:
-            sub_install_req = self._make_install_req(
-                str(subreq),
-                req_to_install,
-            )
+        def add_req(subreq: Requirement, extras_requested: Iterable[str]) -> None:
+            # This idiosyncratically converts the Requirement to str and let
+            # make_install_req then parse it again into Requirement. But this is
+            # the legacy resolver so I'm just not going to bother refactoring.
+            sub_install_req = self._make_install_req(str(subreq), req_to_install)
             parent_req_name = req_to_install.name
             to_scan_again, add_to_parent = requirement_set.add_requirement(
                 sub_install_req,
@@ -410,15 +419,20 @@ class Resolver(BaseResolver):
                         ",".join(req_to_install.extras),
                     )
                 missing_requested = sorted(
-                    set(req_to_install.extras) - set(dist.extras)
+                    set(req_to_install.extras) - set(dist.iter_provided_extras())
                 )
                 for missing in missing_requested:
-                    logger.warning("%s does not provide the extra '%s'", dist, missing)
+                    logger.warning(
+                        "%s %s does not provide the extra '%s'",
+                        dist.raw_name,
+                        dist.version,
+                        missing,
+                    )
 
                 available_requested = sorted(
-                    set(dist.extras) & set(req_to_install.extras)
+                    set(dist.iter_provided_extras()) & set(req_to_install.extras)
                 )
-                for subreq in dist.requires(available_requested):
+                for subreq in dist.iter_dependencies(available_requested):
                     add_req(subreq, extras_requested=available_requested)
 
         return more_reqs
