@@ -415,13 +415,11 @@ class Entry:
         return self.strip_version(version)
 
     @property
-    def updated_specifier(self):
-        # type: () -> str
+    def updated_specifier(self) -> str:
         return self.entry.specifiers
 
     @property
-    def original_specifier(self):
-        # type: () -> str
+    def original_specifier(self) -> str:
         return self.lockfile_entry.specifiers
 
     @property
@@ -830,7 +828,6 @@ def main(argv=None):
     _patch_path(pipenv_site=parsed.pipenv_site)
     import warnings
 
-    from pipenv.vendor.vistir.compat import ResourceWarning
     from pipenv.vendor.vistir.misc import replace_with_text_stream
 
     warnings.simplefilter("ignore", category=ResourceWarning)
